import { ref, watchEffect, unref, watch } from "vue";
const useAutoRunPlugin = (fetchInstance, { manual, ready = true, refreshDeps = [], refreshDepsAction }) => {
  const hasAutoRun = ref(false);
  watchEffect(() => {
    if (!manual)
      hasAutoRun.value = unref(ready);
  });
  watch(
    [hasAutoRun, ...refreshDeps],
    ([autoRun]) => {
      if (!autoRun)
        return;
      if (!manual && autoRun) {
        if (refreshDepsAction) {
          refreshDepsAction();
        } else {
          fetchInstance.refresh();
        }
      }
    },
    {
      deep: true,
      immediate: false
    }
  );
  return {
    onBefore: () => {
      if (!unref(ready)) {
        return {
          stopNow: true
        };
      }
    }
  };
};
useAutoRunPlugin.onInit = ({ initialData, ready = true, manual }) => {
  return {
    loading: !manual && unref(ready)
  };
};
export {
  useAutoRunPlugin as default
};
